@@ -72,11 +72,18 @@ def from_file():
     parser = argparse.ArgumentParser(prog ='pythonplus',
                                      description ='Run a Python+ file using the pythonplus command')
     parser.add_argument('filename', metavar ='filename', type=str, nargs=1, help= 'The filename of the file to run using the Python+ Compiler')
+    parser.add_argument('debug', metavar ='d', type=bool, nargs='?', const=False, help= 'Debug the program by showing the converted Python code?')
     args = parser.parse_args()
     try:
         with open(args.filename[0]) as f:
-            exec(convert(f.read()))
+            python_plus_code = f.read().rstrip()
+            python_code = convert(python_plus_code)
+            if parser.debug:
+                print('\033[2mPython+ Code:\033[0m\n' + python_plus_code + '\n')
+                print('\033[2mPython3 Code:\033[0m\n' + python_code + '\n')
+                print('\033[2mOutput:\033[0m')
+            exec(python_code)
             return 0
     except Exception as e:
-        print('An error occurred:', e)
-    return 1
+        print('\033[1;31mAn error occurred:', e, '\033[0m')
+        return 1
